#!/bin/sh
#*******************************************************************************
# Licensed Materials - Property of IBM
# (c) Copyright IBM Corporation 2012. All Rights Reserved.
#
# Note to U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#*******************************************************************************
# genlink.sh
#   This shellscript is used to inspect existing IBM i *PGM and *SRVPGM objects
#   to find the module and service program bindings and generate source members
#   based on these bindings.
#
#   This shellscript is to be run in IBM i's QSH interpreter.
#
# Example of Usage
#   genlink.sh -inlib=MYPGMLIB -outFs=qsys -outLib=MYSRCLIB -objType=*PGM -workLib=MYTEMPLIB
#
#  Parameters:
#      -inLib=LIBNAME, where LIBNAME is a library containing *PGMs or *SRVPGMs which
#               are to be inspected for their bindings
#      -outFs={qsys | ifs}
#            If qsys, *PGM bindings are written to source file QPGMSRC, member *PGM-name, type PGMSRC.
#                     *SRVPGM bindings are written to source file QSRVPGMSRC, member *SRVPGM-name, type PGMSRC.
#            IF ifs, *PGM and *SRVPGM bindings are written to the -outDir directory,
#                     with .PGMSRC and .SRVPGMSRC extensions, respectively.
#      -outLib=LIBNAME, where LIBNAME is a library to contain generated source files QPGMSRC or QSRVPGMSRC
#      -objType={*pgm | *srvpgm}
#            If *PGM, look for *PGMs to generate PGMSRC for
#            If *SRVPGM, look for *SRVPGMs to generate SRVPGMSRC for
#      -workLib=LIBNAME, where LIBNAME is a working library to contain temporary outputs (e.g. *USRSPC) while inspecting
#            objects from the inLib.
#      -replRefLib={libl,objlib,keep}: Replace referenced library
#            keep=keep bound library names hardcoded as they were found in the existing *PGMs/*SRVPGMs
#            libl=replace bound library names with *LIBL as searchpath
#            objlib=replace bound library names with &OBJLIB variable name.
#      -outDir=IFS_DIR, where IFS_DIR is an IFS directory to write the contents (only if -outFs=ifs)
export JAVA_HOME=/QOpenSys/QIBM/ProdData/JavaVM/jdk60/32bit
export BUILDSYSTEM=/home/babineau/BSTKi.40.M8/jazz/buildsystem
export TOOLKIT_HOME=$BUILDSYSTEM/buildtoolkit
export TOOLKIT_JAR=com.ibm.teamp.build.toolkit_3.1.0.v20120211_1708.jar
export JT400=$BUILDSYSTEM/buildengine/eclipse/plugins/com.ibm.etools.iseries.toolbox_8.0.1.v20110511_2248/runtime/jt400.jar
export CP=$TOOLKIT_JAR:$JT400

export MAINCLASS=com.ibm.teami.build.toolkit.genlink.cli.MainCli

exec $JAVA_HOME/bin/java -cp $CP com.ibm.teami.build.toolkit.genlink.cli.MainCli "$@"

